@@ -357,15 +357,15 @@ class Trainer(object):
     """Evaluate.
 
     Args:
-      inputs_stream: iterable of inputs to evaluate on.
-      weights: weights for each f in eval_fns.
-      state: state for each f in eval_fns.
-      rng: random number generator.
+      inputs_stream: Iterable of inputs to evaluate on.
+      weights: Weights for each f in eval_fns.
+      state: State for each f in eval_fns.
+      rng: Single-use random number generator (JAX PRNG key).
 
     Returns:
-      metrics: dict from metric name to metric value averaged over the number of
-        inputs.
-      state: end state for `predict_fn`.
+      Tuple of `(metrics, state)`. `metrics` is a dict from metric name to
+      metric value averaged over the number of inputs, and `state` is the end
+      state returned by this trainer's `predict_fn`.
     """
     metrics = collections.defaultdict(float)
     count = 0
@@ -537,7 +537,7 @@ def train(output_dir,
           loss_fn=tl.CrossEntropyLoss(),
           inputs=trax_inputs.batcher,
           optimizer=trax_opt.Adafactor,
-          lr_schedule=lr.multifactor(),
+          lr_schedule_fn=lr.multifactor,
           trainer_class=Trainer,
           steps=1000,
           checkpoints_at=None,
@@ -559,8 +559,8 @@ def train(output_dir,
       rng -> loss.
     inputs: callable returning trax.inputs.Inputs.
     optimizer: The optimizer (see optimizers/base.py for signature).
-    lr_schedule: A learning rate schedule as a function that takes history and
-      returns a function from step to learning rate (a float).
+    lr_schedule_fn: A learning rate schedule function, that when called returns
+      a function from step to learning rate (a float).
     trainer_class: The trainer class to use.
     steps: int, total number of training steps.
     checkpoints_at: list of integers. Save a checkpoint for each training step
@@ -582,7 +582,7 @@ def train(output_dir,
     return custom_train_fn(output_dir, model=model)
 
   n_devices = num_devices()
-  trainer = trainer_class(model, loss_fn, optimizer, lr_schedule, inputs,
+  trainer = trainer_class(model, loss_fn, optimizer, lr_schedule_fn(), inputs,
                           output_dir,
                           random_seed=random_seed,
                           n_devices=n_devices,
